@@ -14,11 +14,11 @@ Credits:
 from __future__ import annotations
 
 import re
-
-from typing import Optional, Any, Union, Pattern
 from dataclasses import dataclass, fields
-from enum import Enum, auto as _auto
-from os import name as _name, system
+from enum import Enum
+from os import name as _name
+from os import system
+from typing import Any, Optional, Pattern, Union
 
 from .input import getch
 from .terminal import terminal
@@ -129,13 +129,13 @@ def clear(what: str = "screen") -> None:
 def hide_cursor() -> None:
     """Stops printing the cursor."""
 
-    print("\x1b[?25l")
+    terminal.write("\x1b[?25l")
 
 
 def show_cursor() -> None:
     """Starts printing the cursor."""
 
-    print("\x1b[?25h")
+    terminal.write("\x1b[?25h")
 
 
 def save_cursor() -> None:
@@ -165,7 +165,7 @@ def report_cursor() -> tuple[int, int] | None:
         `report_mouse` if that is what you are interested in.
     """
 
-    print("\x1b[6n")
+    terminal.write("\x1b[6n", flush=True)
     chars = getch()
     posy, posx = chars[2:-1].split(";")
 
@@ -377,30 +377,30 @@ def unset_echo() -> None:
 class MouseAction(Enum):
     """An enumeration of all the polled mouse actions"""
 
-    LEFT_CLICK = _auto()
+    LEFT_CLICK = "left_click"
     """Start of a left button action sequence."""
 
-    LEFT_DRAG = _auto()
+    LEFT_DRAG = "left_drag"
     """Mouse moved while left button was held down."""
 
-    RIGHT_CLICK = _auto()
+    RIGHT_CLICK = "right_click"
     """Start of a right button action sequence."""
 
-    RIGHT_DRAG = _auto()
+    RIGHT_DRAG = "right_drag"
     """Mouse moved while right button was held down."""
 
-    SCROLL_UP = _auto()
+    SCROLL_UP = "scroll_up"
     """Mouse wheel or touchpad scroll upwards."""
 
-    SCROLL_DOWN = _auto()
+    SCROLL_DOWN = "scroll_down"
     """Mouse wheel or touchpad scroll downwards."""
 
-    HOVER = _auto()
+    HOVER = "hover"
     """Mouse moved without clicking."""
 
     # TODO: Support left & right mouse release separately, without breaking
     #       current API.
-    RELEASE = _auto()
+    RELEASE = "release"
     """Mouse button released; end of any and all mouse action sequences."""
 
 
@@ -617,7 +617,7 @@ def print_to(pos: tuple[int, int], *args: Any, **kwargs: Any) -> None:
     """
 
     move_cursor(pos)
-    print(*args, **kwargs, end="", flush=True)
+    print(*args, **kwargs)
 
 
 def reset() -> str:
