@@ -11,23 +11,22 @@ answers I've ever bumped into.
 
 from __future__ import annotations
 
+import colorsys
 import re
 import sys
-from math import sqrt  # pylint: disable=no-name-in-module
 from dataclasses import dataclass, field
-from functools import lru_cache, cached_property
-from typing import TYPE_CHECKING, Type, Literal, Generator
+from functools import cached_property, lru_cache
+from math import sqrt  # pylint: disable=no-name-in-module
+from typing import TYPE_CHECKING, Generator, Literal, Tuple, Type, Union, cast
 
-from .input import getch
-from .fancy_repr import FancyYield
-from .color_table import COLOR_TABLE
-from .exceptions import ColorSyntaxError
-from .terminal import terminal, ColorSystem
 from .ansi_interface import reset as reset_style
+from .color_info import COLOR_TABLE, CSS_COLORS
+from .exceptions import ColorSyntaxError
+from .input import getch
+from .terminal import ColorSystem, terminal
 
 if TYPE_CHECKING:
-    # This cyclic won't be relevant while type checking.
-    from .parser import StyledText  # pylint: disable=cyclic-import
+    from .fancy_repr import FancyYield
 
 __all__ = [
     "COLOR_TABLE",
@@ -56,28 +55,34 @@ RE_PALETTE_REPLY = re.compile(
 PREVIEW_CHAR = "▄▀"
 
 XTERM_NAMED_COLORS = {
-    0: "black",
-    1: "red",
-    2: "green",
-    3: "yellow",
-    4: "blue",
-    5: "magenta",
-    6: "cyan",
-    7: "white",
-    8: "bright-black",
-    9: "bright-red",
-    10: "bright-green",
-    11: "bright-yellow",
-    12: "bright-blue",
-    14: "bright-magenta",
-    15: "bright-cyan",
-    16: "bright-white",
+    0: "ansi-black",
+    1: "ansi-red",
+    2: "ansi-green",
+    3: "ansi-yellow",
+    4: "ansi-blue",
+    5: "ansi-magenta",
+    6: "ansi-cyan",
+    7: "ansi-white",
+    8: "ansi-bright-black",
+    9: "ansi-bright-red",
+    10: "ansi-bright-green",
+    11: "ansi-bright-yellow",
+    12: "ansi-bright-blue",
+    14: "ansi-bright-magenta",
+    15: "ansi-bright-cyan",
+    16: "ansi-bright-white",
 }
 
-NAMED_COLORS = {**{color: str(index) for index, color in XTERM_NAMED_COLORS.items()}}
+NAMED_COLORS = {
+    **CSS_COLORS,
+    **{color: str(index) for index, color in XTERM_NAMED_COLORS.items()},
+}
+
+Number = Union[float, int]
+RGBTriplet = Tuple[Number, Number, Number]
 
 _COLOR_CACHE: dict[str, Color] = {}
-_COLOR_MATCH_CACHE: dict[tuple[float, float, float], Color] = {}
+_COLOR_MATCH_CACHE: dict[RGBTriplet, Color] = {}
 
 
 def clear_color_cache() -> None:
@@ -123,8 +128,9 @@ def _get_palette_color(color: Literal["10", "11"]) -> Color:
     return palette_color
 
 
+# A lot of methods defined here are actually just cached properties.
 @dataclass
-class Color:
+class Color:  # pylint: disable=too-many-public-methods
     """A terminal color.
 
     Args:
@@ -154,8 +160,6 @@ class Color:
     default_foreground: Color | None = field(default=None, repr=False)
     default_background: Color | None = field(default=None, repr=False)
 
-    _luminance: float | None = field(init=False, default=None, repr=False)
-    _brightness: float | None = field(init=False, default=None, repr=False)
     _rgb: tuple[int, int, int] | None = field(init=False, default=None, repr=False)
 
     def __format__(self, spec: str) -> str:
@@ -170,14 +174,32 @@ class Color:
         return repr(self)
 
     @classmethod
-    def from_rgb(cls, rgb: tuple[int, int, int]) -> Color:
-        """Creates a color from the given RGB, within terminal's colorsystem.
+    def from_rgb(cls, rgb: RGBTriplet) -> Color:
+        """Creates a color from the given RGB.
 
         Args:
             rgb: The RGB value to base the new color off of.
         """
 
-        raise NotImplementedError
+        return RGBColor.from_rgb(rgb)
+
+    @classmethod
+    def from_hls(cls, hsl: RGBTriplet) -> Color:
+        """Creates a color from the given HLS.
+
+        HLS stands for Hue, Lightness & Saturation. It is more commonly known as HSL,
+        but the `colorsys` library uses HLS instead so that's what we use too.
+
+        Args:
+            hsl: The HLS value to base the new color off of.
+        """
+
+        rgb = cast(
+            RGBTriplet,
+            map(lambda n: int(256 * n), colorsys.hls_to_rgb(*hsl)),
+        )
+
+        return RGBColor.from_rgb(rgb)
 
     @property
     def sequence(self) -> str:
@@ -192,7 +214,7 @@ class Color:
         return ("@" if self.background else "") + self.value
 
     @cached_property
-    def rgb(self) -> tuple[int, int, int]:
+    def rgb(self) -> RGBTriplet:
         """Returns this color as a tuple of (red, green, blue) values."""
 
         if self._rgb is None:
@@ -200,7 +222,49 @@ class Color:
 
         return self._rgb
 
-    @property
+    @cached_property
+    def red(self) -> Number:
+        """Returns the red component of this color."""
+
+        return self.rgb[0]
+
+    @cached_property
+    def green(self) -> Number:
+        """Returns the red component of this color."""
+
+        return self.rgb[1]
+
+    @cached_property
+    def blue(self) -> Number:
+        """Returns the red component of this color."""
+
+        return self.rgb[2]
+
+    @cached_property
+    def hls(self) -> RGBTriplet:
+        """Returns the HLS (Hue, Lightness, Saturation) representation of this color."""
+
+        return colorsys.rgb_to_hls(self.red / 256, self.green / 256, self.blue / 256)
+
+    @cached_property
+    def hue(self) -> float:
+        """Returns the hue component of this color."""
+
+        return self.hls[0]
+
+    @cached_property
+    def lightness(self) -> float:
+        """Returns the lightness component of this color."""
+
+        return self.hls[1]
+
+    @cached_property
+    def saturation(self) -> float:
+        """Returns the saturation component of this color."""
+
+        return self.hls[2]
+
+    @cached_property
     def hex(self) -> str:
         """Returns CSS-like HEX representation of this color."""
 
@@ -234,17 +298,13 @@ class Color:
 
         return ("@" if self.background else "") + self.value
 
-    @property
+    @cached_property
     def luminance(self) -> float:
         """Returns this color's perceived luminance (brightness).
 
         From https://stackoverflow.com/a/596243
         """
 
-        # Don't do expensive calculations over and over
-        if self._luminance is not None:
-            return self._luminance
-
         def _linearize(color: float) -> float:
             """Converts sRGB color to linear value."""
 
@@ -263,42 +323,181 @@ class Color:
         blue = _linearize(blue)
         green = _linearize(green)
 
-        self._luminance = 0.2126 * red + 0.7152 * green + 0.0722 * blue
+        return 0.2126 * red + 0.7152 * green + 0.0722 * blue
 
-        return self._luminance
+    def hue_offset(self, offset: float) -> Color:
+        """Returns the color offset by the given hue."""
 
-    @property
+        hue, lightness, saturation = colorsys.rgb_to_hls(
+            self.red / 256, self.green / 256, self.blue / 256
+        )
+
+        hue = (hue + offset) % 1
+
+        return Color.parse(
+            ";".join(
+                map(
+                    lambda n: str(int(256 * n)),
+                    colorsys.hls_to_rgb(hue, lightness, saturation),
+                )
+            ),
+            background=self.background,
+            localize=False,
+        )
+
+    @cached_property
     def brightness(self) -> float:
         """Returns the perceived "brightness" of a color.
 
         From https://stackoverflow.com/a/56678483
         """
 
-        # Don't do expensive calculations over and over
-        if self._brightness is not None:
-            return self._brightness
-
         if self.luminance <= (216 / 24389):
             brightness = self.luminance * (24389 / 27)
 
         else:
             brightness = self.luminance ** (1 / 3) * 116 - 16
 
-        self._brightness = brightness / 100
-        return self._brightness
+        return brightness / 100
 
-    def __call__(self, text: str, reset: bool = True) -> StyledText:
-        """Colors the given string, returning a `pytermgui.parser.StyledText`."""
+    @cached_property
+    def complement(self) -> Color:
+        """Returns the complement of this color."""
 
-        # We import this here as toplevel would cause circular imports, and it won't
-        # be used until this method is called anyways.
-        from .parser import StyledText  # pylint: disable=import-outside-toplevel
+        if self.hue == 0.0:
+            return (
+                Color.parse("#FFFFFF")
+                if self.lightness == 0.0
+                else Color.parse("#000000")
+            )
+
+        return self.hue_offset(0.5)
+
+    @cached_property
+    def triadic(self) -> tuple[Color, Color, Color]:
+        """Computes the triadic group this color is in.
+
+        Triadic colors are 3-way complements of eachother.
+
+        Returns:
+            This color, the first triadic element and the second one.
+        """
+
+        return self, self.hue_offset(1 / 3), self.hue_offset(2 / 3)
+
+    @cached_property
+    def tetradic(self) -> tuple[Color, Color, Color, Color]:
+        """Computes the tetradic group this color is in.
+
+        Tetradic colors are 4-way complements of eachother.
+
+        Returns:
+            This color, the first tetradic element and the second one.
+        """
+
+        return self, self.hue_offset(1 / 4), self.complement, self.hue_offset(3 / 4)
+
+    @cached_property
+    def analogous(self) -> tuple[Color, Color, Color]:
+        """Computes the analogous group this colors is in.
+
+        Analogous colors are located next to eachother on the color wheel.
+
+        Returns:
+            The color to the left, this color and the color to the right.
+        """
+
+        return self.hue_offset(-1 / 12), self, self.hue_offset(1 / 12)
+
+    @cached_property
+    def contrast(self) -> Color:
+        """Returns a color (black or white) that complies with the W3C contrast ratio guidelines."""
+
+        if self.luminance > 0.179:
+            return Color.parse("#000000").blend_complement(0.05)
+
+        return Color.parse("#FFFFFF").blend_complement(0.05)
+
+    def blend(self, other: Color, alpha: float = 0.5, localize: bool = False) -> Color:
+        """Blends a color into another one.
+
+        Args:
+            other: The color to blend with.
+            alpha: How much the other color should influence the outcome.
+            localize: If set, the returned color will returned its localized version by running
+                `get_localized` on it before returning.
+
+        Returns:
+            A `Color` that is the result of the blending.
+        """
+
+        red1, green1, blue1 = self.rgb
+        red2, green2, blue2 = other.rgb
+
+        blended: Color = RGBColor.from_rgb(
+            (
+                int(red1 + (red2 - red1) * alpha),
+                int(green1 + (green2 - green1) * alpha),
+                int(blue1 + (blue2 - blue1) * alpha),
+            )
+        )
+
+        if localize:
+            blended = blended.get_localized()
+
+        return blended
+
+    def blend_complement(self, alpha: float = 0.5) -> Color:
+        """Blends this color with its complement.
+
+        See `Color.blend`.
+        """
+
+        return self.blend(self.complement, alpha)
+
+    def blend_contrast(self, alpha: float = 0.5) -> Color:
+        """Blends this color with its contrast pair.
+
+        See `Color.blend`.
+        """
+
+        return self.blend(self.contrast, alpha)
+
+    def darken(self, alpha: float = 0.5) -> Color:
+        """Darkens the color by blending it with black, using the alpha provided."""
+
+        return self.blend(Color.parse("#000000"), alpha)
+
+    def lighten(self, alpha: float = 0.5) -> Color:
+        """Lightens the color by blending it with white, using the alpha provided."""
+
+        return self.blend(Color.parse("#FFFFFF"), alpha)
+
+    @classmethod
+    def parse(
+        cls,
+        text: str,
+        background: bool = False,  # pylint: disable=redefined-outer-name
+        localize: bool = True,
+        use_cache: bool = False,
+    ) -> Color:
+        """Uses `str_to_color` to parse some text into a `Color`."""
+
+        return str_to_color(
+            text=text,
+            is_background=background,
+            localize=localize,
+            use_cache=use_cache,
+        )
+
+    def __call__(self, text: str, reset: bool = True) -> str:
+        """Colors the given string."""
 
         buff = self.sequence + text
         if reset:
             buff += reset_style()
 
-        return StyledText(buff)
+        return buff
 
     def get_localized(self) -> Color:
         """Creates a terminal-capability local Color instance.
@@ -348,7 +547,7 @@ class IndexedColor(Color):
         yield ">"
 
     @classmethod
-    def from_rgb(cls, rgb: tuple[int, int, int]) -> IndexedColor:
+    def from_rgb(cls, rgb: RGBTriplet) -> IndexedColor:
         """Constructs an `IndexedColor` from the closest matching option."""
 
         if rgb in _COLOR_MATCH_CACHE:
@@ -383,7 +582,7 @@ class IndexedColor(Color):
         return "\x1b[" + ("48" if self.background else "38") + f";5;{index}m"
 
     @cached_property
-    def rgb(self) -> tuple[int, int, int]:
+    def rgb(self) -> RGBTriplet:
         """Returns an RGB representation of this color."""
 
         if self._rgb is not None:
@@ -442,7 +641,7 @@ class StandardColor(IndexedColor):
         return cls(str(code_int), background=is_background)
 
     @classmethod
-    def from_rgb(cls, rgb: tuple[int, int, int]) -> StandardColor:
+    def from_rgb(cls, rgb: RGBTriplet) -> StandardColor:
         """Creates a color with the closest-matching xterm index, based on rgb.
 
         Args:
@@ -482,7 +681,7 @@ class StandardColor(IndexedColor):
         return f"\x1b[{index}m"
 
     @cached_property
-    def rgb(self) -> tuple[int, int, int]:
+    def rgb(self) -> RGBTriplet:
         """Returns an RGB representation of this color."""
 
         index = int(self.value)
@@ -505,7 +704,7 @@ class GreyscaleRampColor(IndexedColor):
     """
 
     @classmethod
-    def from_rgb(cls, rgb: tuple[int, int, int]) -> GreyscaleRampColor:
+    def from_rgb(cls, rgb: RGBTriplet) -> GreyscaleRampColor:
         """Gets a greyscale color based on the given color's luminance."""
 
         color = cls("0")
@@ -548,25 +747,25 @@ class RGBColor(Color):
         yield ">"
 
     @classmethod
-    def from_rgb(cls, rgb: tuple[int, int, int]) -> RGBColor:
+    def from_rgb(cls, rgb: RGBTriplet) -> RGBColor:
         """Returns an `RGBColor` from the given triplet."""
 
         return cls(";".join(map(str, rgb)))
 
-    @cached_property
-    def red(self) -> int:
+    @property
+    def red(self) -> float:
         """Returns the red component of this color."""
 
         return self.rgb[0]
 
-    @cached_property
-    def green(self) -> int:
+    @property
+    def green(self) -> float:
         """Returns the green component of this color."""
 
         return self.rgb[1]
 
-    @cached_property
-    def blue(self) -> int:
+    @property
+    def blue(self) -> float:
         """Returns the blue component of this color."""
 
         return self.rgb[2]
@@ -607,24 +806,6 @@ class HEXColor(RGBColor):
 
         assert len(self._rgb) == 3
 
-    @property
-    def red(self) -> int:
-        """Returns the red component of this color."""
-
-        return int(self.value[1:3])
-
-    @property
-    def green(self) -> int:
-        """Returns the green component of this color."""
-
-        return int(self.value[3:5])
-
-    @property
-    def blue(self) -> int:
-        """Returns the blue component of this color."""
-
-        return int(self.value[5:7])
-
 
 SYSTEM_TO_TYPE: dict[ColorSystem, Type[Color]] = {
     ColorSystem.NO_COLOR: GreyscaleRampColor,
@@ -634,9 +815,7 @@ SYSTEM_TO_TYPE: dict[ColorSystem, Type[Color]] = {
 }
 
 
-def _get_color_difference(
-    rgb1: tuple[int, int, int], rgb2: tuple[int, int, int]
-) -> float:
+def _get_color_difference(rgb1: RGBTriplet, rgb2: RGBTriplet) -> float:
     """Gets the geometric difference of 2 RGB colors (0-255).
 
     See https://en.wikipedia.org/wiki/Color_difference's Euclidian section.
@@ -658,12 +837,12 @@ def _get_color_difference(
     )
 
 
-@lru_cache(maxsize=None)
+@lru_cache(maxsize=1024)
 def str_to_color(
     text: str,
     is_background: bool = False,
     localize: bool = True,
-    use_cache: bool = False,
+    use_cache: bool = True,
 ) -> Color:
     """Creates a `Color` from the given text.
 
@@ -687,6 +866,9 @@ def str_to_color(
     def _trim_code(code: str) -> str:
         """Trims the given color code."""
 
+        if not all(char.isdigit() or char in "m;" for char in code):
+            return code
+
         is_background = code.startswith("48;")
 
         if (code.startswith("38;5;") or code.startswith("48;5;")) or (
@@ -730,13 +912,13 @@ def str_to_color(
 
     match = RE_HEX.match(text)
     if match is not None:
-        color = HEXColor(match[0], background=is_background).get_localized()
+        color = HEXColor(match[0], background=is_background)
 
         return color.get_localized() if localize else color
 
     match = RE_RGB.match(text)
     if match is not None:
-        color = RGBColor(match[0], background=is_background).get_localized()
+        color = RGBColor(match[0], background=is_background)
 
         return color.get_localized() if localize else color
 
