@@ -10,16 +10,16 @@ from __future__ import annotations
 
 from copy import deepcopy
 from inspect import signature
-from typing import Callable, Optional, Type, Iterator, Any, Union, Generator
+from typing import Any, Callable, Generator, Iterator, Optional, Type, Union
 
-from ..input import keys
-from ..parser import markup
-from ..regex import real_length
+from ..ansi_interface import MouseAction, MouseEvent, reset
+from ..enums import HorizontalAlignment, SizePolicy, WidgetChange
+from ..fancy_repr import FancyYield
 from ..helpers import break_line
-from ..terminal import get_terminal, Terminal
-from ..ansi_interface import MouseEvent, reset
-from ..enums import SizePolicy, HorizontalAlignment, WidgetChange
-
+from ..input import keys
+from ..markup import get_markup
+from ..regex import real_length
+from ..terminal import Terminal, get_terminal
 from . import styles as w_styles
 
 __all__ = ["Widget", "Label"]
@@ -144,6 +144,8 @@ class Widget:  # pylint: disable=too-many-public-methods
         self._relative_width: float | None = None
         self._previous_state: tuple[tuple[int, int], list[str]] | None = None
 
+        self.positioned_line_buffer: list[tuple[tuple[int, int], str]] = []
+
         for attr, value in attrs.items():
             setattr(self, attr, value)
 
@@ -156,7 +158,7 @@ class Widget:  # pylint: disable=too-many-public-methods
 
         return self.debug()
 
-    def __fancy_repr__(self) -> Generator[str, None, None]:
+    def __fancy_repr__(self) -> Generator[FancyYield, None, None]:
         """Yields the repr of this object, then a preview of it."""
 
         yield self.debug()
@@ -340,7 +342,7 @@ class Widget:  # pylint: disable=too-many-public-methods
 
         Returns:
             Boolean describing whether the position is inside
-              this widget.
+                this widget.
         """
 
         rect = self.pos, (
@@ -353,23 +355,59 @@ class Widget:  # pylint: disable=too-many-public-methods
         return left <= pos[0] < right and top <= pos[1] < bottom
 
     def handle_mouse(self, event: MouseEvent) -> bool:
-        """Handles a mouse event, returning its success.
+        """Tries to call the most specific mouse handler function available.
+
+        This function looks for a set of mouse action handlers. Each handler follows
+        the format
+
+            on_{event_name}
+
+        For example, the handler triggered on MouseAction.LEFT_CLICK would be
+        `on_left_click`. If no handler is found nothing is done.
+
+        You can also define more general handlers, for example to group left & right
+        clicks you can use `on_click`, and to catch both up and down scroll you can use
+        `on_scroll`. General handlers are only used if they are the most specific ones,
+        i.e. there is no "specific" handler.
 
         Args:
-            event: Object containing mouse event to handle.
+            event: The event to handle.
 
         Returns:
-            A boolean describing whether the mouse input was handled."""
+            Whether the parent of this widget should treat it as one to "stick" events
+            to, e.g. to keep sending mouse events to it. One can "unstick" a widget by
+            returning False in the handler.
+        """
 
-        return False and hasattr(self, event)
+        def _get_names(action: MouseAction) -> tuple[str, ...]:
+            if action.value in ["hover", "release"]:
+                return (action.value,)
+
+            parts = action.value.split("_")
+
+            # left click & right click
+            if parts[0] in ["left", "right"]:
+                return (action.value, parts[1])
+
+            # scroll up & down
+            return (action.value, parts[0])
+
+        possible_names = _get_names(event.action)
+        for name in possible_names:
+            if hasattr(self, f"on_{name}"):
+                handle = getattr(self, f"on_{name}")
+
+                return handle(event)
+
+        return False
 
     def handle_key(self, key: str) -> bool:
         """Handles a mouse event, returning its success.
 
         Args:
             key: String representation of input string.
-              The `pytermgui.input.keys` object can be
-              used to retrieve special keys.
+                The `pytermgui.input.keys` object can be
+                used to retrieve special keys.
 
         Returns:
             A boolean describing whether the key was handled.
@@ -418,9 +456,9 @@ class Widget:  # pylint: disable=too-many-public-methods
             if style:
                 style_call = self._get_style(key)
                 if isinstance(value, list):
-                    out[key] = [markup.get_markup(style_call(char)) for char in value]
+                    out[key] = [get_markup(style_call(char)) for char in value]
                 else:
-                    out[key] = markup.get_markup(style_call(value))
+                    out[key] = get_markup(style_call(value))
 
                 continue
 
@@ -432,11 +470,9 @@ class Widget:  # pylint: disable=too-many-public-methods
             style_call = self._get_style(key)
 
             if isinstance(value, list):
-                out["chars"][key] = [
-                    markup.get_markup(style_call(char)) for char in value
-                ]
+                out["chars"][key] = [get_markup(style_call(char)) for char in value]
             else:
-                out["chars"][key] = markup.get_markup(style_call(value))
+                out["chars"][key] = get_markup(style_call(value))
 
         return out
 
@@ -539,7 +575,7 @@ class Widget:  # pylint: disable=too-many-public-methods
 
         del self._bindings[key]
 
-    def execute_binding(self, key: Any) -> bool:
+    def execute_binding(self, key: Any, ignore_any: bool = False) -> bool:
         """Executes a binding belonging to key, when present.
 
         Use this method inside custom widget `handle_keys` methods, or to run a callback
@@ -547,15 +583,16 @@ class Widget:  # pylint: disable=too-many-public-methods
 
         Args:
             key: Usually a string, indexing into the `_bindings` dictionary. These are the
-              same strings as defined in `Widget.bind`.
+                same strings as defined in `Widget.bind`.
+            ignore_any: If set, `keys.ANY_KEY` bindings will not be executed.
 
         Returns:
             True if the binding was found, False otherwise. Bindings will always be
-              executed if they are found.
+                executed if they are found.
         """
 
         # Execute special binding
-        if keys.ANY_KEY in self._bindings:
+        if not ignore_any and keys.ANY_KEY in self._bindings:
             method, _ = self._bindings[keys.ANY_KEY]
             method(self, key)
 
@@ -664,7 +701,7 @@ class Label(Widget):
     """
 
     serialized = Widget.serialized + ["*value", "align", "padding"]
-    styles = w_styles.StyleManager(value=w_styles.MARKUP)
+    styles = w_styles.StyleManager(value="")
 
     def __init__(
         self,
