@@ -6,23 +6,23 @@
 
 from __future__ import annotations
 
+from copy import deepcopy
 from itertools import zip_longest
 from typing import Any, Callable, Iterator, cast
 
 from ..ansi_interface import MouseAction, MouseEvent, clear, reset
 from ..context_managers import cursor_at
 from ..enums import (
-    HorizontalAlignment,
-    VerticalAlignment,
     CenteringPolicy,
-    WidgetChange,
-    SizePolicy,
+    HorizontalAlignment,
     Overflow,
+    SizePolicy,
+    VerticalAlignment,
+    WidgetChange,
 )
-
 from ..exceptions import WidthExceededError
-from ..regex import real_length, strip_markup
 from ..input import keys
+from ..regex import real_length, strip_markup
 from . import boxes
 from . import styles as w_styles
 from .base import ScrollableWidget, Widget
@@ -32,9 +32,9 @@ class Container(ScrollableWidget):
     """A widget that displays other widgets, stacked vertically."""
 
     styles = w_styles.StyleManager(
-        border=w_styles.MARKUP,
-        corner=w_styles.MARKUP,
-        fill=w_styles.BACKGROUND,
+        border="surface",
+        corner="surface",
+        fill="background",
     )
 
     chars: dict[str, w_styles.CharType] = {
@@ -75,10 +75,16 @@ class Container(ScrollableWidget):
         for widget in widgets:
             self._add_widget(widget)
 
-        if "box" in attrs:
-            self.box = attrs["box"]
+        if "box" not in attrs:
+            attrs["box"] = "SINGLE"
 
-        self._drag_target: Widget | None = None
+        try:
+            self.box = attrs["box"]
+        # Splitter doesn't use boxes ATM.
+        except KeyError:
+            pass
+
+        self._mouse_target: Widget | None = None
 
     @property
     def sidelength(self) -> int:
@@ -224,7 +230,7 @@ class Container(ScrollableWidget):
 
         Args:
             other: Any widget instance, or data structure that can be turned
-            into a widget by `Widget.from_data`.
+                into a widget by `Widget.from_data`.
 
         Returns:
             A reference to self.
@@ -234,20 +240,20 @@ class Container(ScrollableWidget):
         return self
 
     def __add__(self, other: object) -> Container:
-        """Adds a new widget, then returns self.
-
-        This method is analogous to `Container.__iadd__`.
+        """Creates a copy of self and adds `other` to it.
 
         Args:
             other: Any widget instance, or data structure that can be turned
-            into a widget by `Widget.from_data`.
+                into a widget by `Widget.from_data`.
 
         Returns:
-            A reference to self.
+            A reference to the copy.
         """
 
-        self.__iadd__(other)
-        return self
+        new = deepcopy(self)
+        new += self
+
+        return new
 
     def __iter__(self) -> Iterator[Widget]:
         """Gets an iterator of self._widgets.
@@ -371,7 +377,7 @@ class Container(ScrollableWidget):
             """Align line to the left"""
 
             padding = self.width - real_length(left + right) - real_length(text)
-            return left + fill(text) + fill(padding * char) + right
+            return left + text + fill(padding * char) + right
 
         def _align_center(text: str) -> str:
             """Align line to the center"""
@@ -390,7 +396,7 @@ class Container(ScrollableWidget):
             """Align line to the right"""
 
             padding = self.width - real_length(left + right) - real_length(text)
-            return left + fill(padding * char + text) + right
+            return left + fill(padding * char) + text + right
 
         if widget.parent_align == HorizontalAlignment.CENTER:
             total = self.width - real_length(left + right) - widget.width
@@ -581,8 +587,14 @@ class Container(ScrollableWidget):
             widget.pos = (widget.pos[0], widget.pos[1] + vertical_offset)
 
             if widget.is_selectable:
+                # This buffer will be out of position, so we must clear it.
+                widget.positioned_line_buffer = []
                 widget.get_lines()
 
+            self.positioned_line_buffer.extend(widget.positioned_line_buffer)
+
+            widget.positioned_line_buffer = []
+
         if has_top_bottom[0]:
             lines.insert(0, _get_border(corners[0], borders[1], corners[1]))
 
@@ -640,7 +652,7 @@ class Container(ScrollableWidget):
         Analogous to self._widgets.remove(other).
 
         Args:
-            widget: The widget to remove.
+            other: The widget to remove.
         """
 
         return self._widgets.remove(other)
@@ -725,31 +737,60 @@ class Container(ScrollableWidget):
         return self
 
     def handle_mouse(self, event: MouseEvent) -> bool:
-        """Applies a mouse event on all children.
+        """Handles mouse events.
+
+        This, like all mouse handlers should, calls super()'s implementation first,
+        to allow usage of `on_{event}`-type callbacks. After that, it tries to find
+        a target widget within itself to handle the event.
+
+        Each handler will return a boolean. This boolean is then used to figure out
+        whether the targeted widget should be "sticky", i.e. a slider. Returning
+        True will set that widget as the current mouse target, and all mouse events will
+        be sent to it as long as it returns True.
 
         Args:
-            event: The event to handle
+            event: The event to handle.
 
         Returns:
-            A boolean showing whether the event was handled.
+            Whether the parent of this widget should treat it as one to "stick" events
+            to, e.g. to keep sending mouse events to it. One can "unstick" a widget by
+            returning False in the handler.
         """
 
-        if event.action is MouseAction.RELEASE:
-            # Force RELEASE event to be sent
-            if self._drag_target is not None:
-                self._drag_target.handle_mouse(
-                    MouseEvent(MouseAction.RELEASE, event.position)
-                )
+        def _handle_scrolling() -> bool:
+            """Scrolls the container."""
 
-            self._drag_target = None
+            if self.overflow != Overflow.SCROLL:
+                return False
 
-        if self._drag_target is not None:
-            return self._drag_target.handle_mouse(event)
+            if event.action is MouseAction.SCROLL_UP:
+                return self.scroll(-1)
+
+            if event.action is MouseAction.SCROLL_DOWN:
+                return self.scroll(1)
+
+            return False
+
+        if super().handle_mouse(event):
+            return True
+
+        if event.action is MouseAction.RELEASE and self._mouse_target is not None:
+            return self._mouse_target.handle_mouse(event)
+
+        if (
+            self._mouse_target is not None
+            and (
+                event.action.value.endswith("drag")
+                or event.action.value.startswith("scroll")
+            )
+            and self._mouse_target.handle_mouse(event)
+        ):
+            return True
+
+        release = MouseEvent(MouseAction.RELEASE, event.position)
 
         selectables_index = 0
-        scrolled_pos = list(event.position)
-        scrolled_pos[1] += self._scroll_offset
-        event.position = (scrolled_pos[0], scrolled_pos[1])
+        event.position = (event.position[0], event.position[1] + self._scroll_offset)
 
         handled = False
         for widget in self._widgets:
@@ -761,30 +802,28 @@ class Container(ScrollableWidget):
 
             if widget.contains(event.position):
                 handled = widget.handle_mouse(event)
-                # This avoids too many branches from pylint.
                 selectables_index += widget.selected_index or 0
 
+                # TODO: This really should be customizable somehow.
                 if event.action is MouseAction.LEFT_CLICK:
-                    self._drag_target = widget
-
                     if handled and selectables_index < len(self.selectables):
                         self.select(selectables_index)
 
+                if self._mouse_target is not None and self._mouse_target is not widget:
+                    self._mouse_target.handle_mouse(release)
+
+                self._mouse_target = widget
+
                 break
 
             if widget.is_selectable:
                 selectables_index += widget.selectables_length
 
-        if not handled and self.overflow == Overflow.SCROLL:
-            if event.action is MouseAction.SCROLL_UP:
-                return self.scroll(-1)
-
-            if event.action is MouseAction.SCROLL_DOWN:
-                return self.scroll(1)
+        handled = handled or _handle_scrolling()
 
         return handled
 
-    def execute_binding(self, key: str) -> bool:
+    def execute_binding(self, key: Any, ignore_any: bool = False) -> bool:
         """Executes a binding on self, and then on self._widgets.
 
         If a widget.execute_binding call returns True this function will too. Note
@@ -793,12 +832,13 @@ class Container(ScrollableWidget):
 
         Args:
             key: The binding key.
+            ignore_any: If set, `keys.ANY_KEY` bindings will not be executed.
 
         Returns:
             True if any widget returned True, False otherwise.
         """
 
-        if super().execute_binding(key):
+        if super().execute_binding(key, ignore_any=ignore_any):
             return True
 
         selectables_index = 0
@@ -938,7 +978,7 @@ class Container(ScrollableWidget):
 class Splitter(Container):
     """A widget that displays other widgets, stacked horizontally."""
 
-    styles = w_styles.StyleManager(separator=w_styles.MARKUP, fill=w_styles.BACKGROUND)
+    styles = w_styles.StyleManager(separator="surface", fill="background")
 
     chars: dict[str, list[str] | str] = {"separator": " | "}
     keys = {
@@ -1023,9 +1063,5 @@ class Splitter(Container):
         for horizontal in zip_longest(*vertical_lines, fillvalue=" " * target_width):
             lines.append((reset() + separator).join(horizontal))
 
+        self.height = max(widget.height for widget in self)
         return lines
-
-    def debug(self) -> str:
-        """Return identifiable information"""
-
-        return super().debug().replace("Container", "Splitter", 1)
