@@ -7,16 +7,18 @@ that represents that "deep" the Widget is within the hierarchy, and
 """
 
 # pylint: disable=unused-argument, too-many-instance-attributes
+# pylint: disable=unnecessary-lambda-assignment
 
 from __future__ import annotations
 
 from collections import UserDict
 from dataclasses import dataclass, field
-from typing import Callable, Union, List, Type, TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Callable, List, Type, Union
 
-from ..regex import strip_ansi
-from ..parser import tim, RE_MARKUP
 from ..highlighters import Highlighter
+from ..markup import Token, get_markup, tim, tokenize_markup
+from ..markup.parsing import _sub_aliases
+from ..regex import RE_MARKUP, strip_ansi
 
 __all__ = [
     "MarkupFormatter",
@@ -26,11 +28,6 @@ __all__ = [
     "StyleManager",
     "DepthlessStyleType",
     "CharType",
-    "MARKUP",
-    "FOREGROUND",
-    "BACKGROUND",
-    "CLICKABLE",
-    "CLICKED",
 ]
 
 if TYPE_CHECKING:
@@ -68,7 +65,7 @@ class StyleCall:
         # this is purposefully broad, as anything can happen during these calls.
         except Exception as error:
             raise RuntimeError(
-                f'Could not apply style {self.method} to "{item}": {error}'  # type: ignore
+                f"Could not apply style {self.method} to {item!r}: {error}"  # type: ignore
             ) from error
 
     def __eq__(self, other: object) -> bool:
@@ -110,7 +107,7 @@ class MarkupFormatter:
 
         else:
             original = item
-            item = tim.get_markup(item)
+            item = get_markup(item)
             self._markup_cache[original] = item
 
         return tim.parse(self.markup.format(depth=depth, item=item))
@@ -215,7 +212,16 @@ class StyleManager(UserDict):  # pylint: disable=too-many-ancestors
         if RE_MARKUP.match(shorthand) is not None:
             return MarkupFormatter(shorthand)
 
-        markup = "[" + shorthand + "]"
+        tokens = _sub_aliases(tokenize_markup(f"[{shorthand}]"), tim.context)
+
+        colors = [tkn for tkn in tokens if Token.is_color(tkn)]
+
+        if any(tkn.color.background for tkn in colors) and not any(
+            not tkn.color.background for tkn in colors
+        ):
+            shorthand += " #auto"
+
+        markup = f"[{shorthand}]"
 
         if not "{item}" in shorthand:
             markup += "{item}"
@@ -223,7 +229,7 @@ class StyleManager(UserDict):  # pylint: disable=too-many-ancestors
         return MarkupFormatter(markup)
 
     @classmethod
-    def merge(cls, other: StyleManager, **styles) -> StyleManager:
+    def merge(cls, other: StyleManager, **styles: str) -> StyleManager:
         """Creates a new manager that merges `other` with the passed in styles.
 
         Args:
@@ -330,19 +336,3 @@ class StyleManager(UserDict):  # pylint: disable=too-many-ancestors
             self._set_as_stylecall(key, value)
 
         return self.parent
-
-
-CLICKABLE = MarkupFormatter("[@238 72 bold]{item}")
-"""Style for inactive clickable things, such as `pytermgui.widgets.Button`"""
-
-CLICKED = MarkupFormatter("[238 @72 bold]{item}")
-"""Style for active clickable things, such as `pytermgui.widgets.Button`"""
-
-FOREGROUND = lambda _, item: item
-"""Standard foreground style, currently unused by the library"""
-
-BACKGROUND = lambda _, item: item
-"""Standard background, used by most `fill` styles"""
-
-MARKUP = lambda depth, item: tim.parse(item)
-"""Style that parses value as markup. Used by most text labels, like `pytermgui.widgets.Label`"""
