@@ -3,23 +3,23 @@ while letting `Compositor` draw them."""
 
 from __future__ import annotations
 
-from enum import Enum, auto as _auto
-from typing import Type, Any, Iterator
+from enum import Enum
+from enum import auto as _auto
+from typing import Any, Iterator, Type
 
-from ..input import getch
+from ..animations import Animation, AttrAnimation, FloatAnimation, animator
+from ..ansi_interface import MouseAction, MouseEvent
+from ..colors import str_to_color
+from ..context_managers import MouseTranslator, alt_buffer, mouse_handler
 from ..enums import Overflow
+from ..input import getch
 from ..regex import real_length
 from ..terminal import terminal
-from ..colors import str_to_color
-from ..widgets import Widget, Container
+from ..widgets import Container, Widget
 from ..widgets.base import BoundCallback
-from ..ansi_interface import MouseAction, MouseEvent
-from ..context_managers import alt_buffer, mouse_handler, MouseTranslator
-from ..animations import animator, AttrAnimation, FloatAnimation, Animation
-
-from .window import Window
-from .layouts import Layout
 from .compositor import Compositor
+from .layouts import Layout
+from .window import Window
 
 
 def _center_during_animation(animation: AttrAnimation) -> None:
@@ -53,12 +53,14 @@ class WindowManager(Widget):  # pylint: disable=too-many-instance-attributes
     focusing_actions = (MouseAction.LEFT_CLICK, MouseAction.RIGHT_CLICK)
     """These mouse actions will focus the window they are acted upon."""
 
+    autorun = True
+
     def __init__(
         self,
         *,
-        autorun: bool = True,
         layout_type: Type[Layout] = Layout,
         framerate: int = 60,
+        autorun: bool | None = None,
     ) -> None:
         """Initialize the manager."""
 
@@ -66,16 +68,21 @@ class WindowManager(Widget):  # pylint: disable=too-many-instance-attributes
 
         self._is_running = False
         self._windows: list[Window] = []
-        self._drag_offsets: tuple[int, int] = (0, 0)
-        self._drag_target: tuple[Window, Edge] | None = None
         self._bindings: dict[str | Type[MouseEvent], tuple[BoundCallback, str]] = {}
 
         self.focused: Window | None = None
-        self.autorun = autorun
+
+        if autorun is not None:
+            self.autorun = autorun
+
         self.layout = layout_type()
         self.compositor = Compositor(self._windows, framerate=framerate)
         self.mouse_translator: MouseTranslator | None = None
 
+        self._mouse_target: Window | None = None
+        self._drag_offsets: tuple[int, int] = (0, 0)
+        self._drag_target: tuple[Window, Edge] | None = None
+
         # This isn't quite implemented at the moment.
         self.restrict_within_bounds = True
 
@@ -498,12 +505,28 @@ class WindowManager(Widget):  # pylint: disable=too-many-instance-attributes
                 ):
                     break
 
-                if window.handle_mouse(event) or (contains or window.is_modal):
+                if contains:
+                    if self._mouse_target is not None:
+                        self._mouse_target.handle_mouse(
+                            MouseEvent(MouseAction.RELEASE, event.position)
+                        )
+
+                    self._mouse_target = window
+                    window.handle_mouse(event)
+                    break
+
+                if window.is_modal:
                     break
 
             # Unset drag_target if no windows received the input
             else:
                 self._drag_target = None
+                if self._mouse_target is not None:
+                    self._mouse_target.handle_mouse(
+                        MouseEvent(MouseAction.RELEASE, event.position)
+                    )
+
+                self._mouse_target = None
 
     def screenshot(self, title: str, filename: str = "screenshot.svg") -> None:
         """Takes a screenshot of the current state.
@@ -546,7 +569,7 @@ class WindowManager(Widget):  # pylint: disable=too-many-instance-attributes
 
         getch()
 
-    def alert(self, *items, center: bool = True, **attributes) -> Window:
+    def alert(self, *items: Any, center: bool = True, **attributes: Any) -> Window:
         """Creates a modal popup of the given elements and attributes.
 
         Args:
@@ -566,11 +589,11 @@ class WindowManager(Widget):  # pylint: disable=too-many-instance-attributes
 
     def toast(
         self,
-        *items,
+        *items: Any,
         offset: int = 0,
         duration: int = 300,
         delay: int = 1000,
-        **attributes,
+        **attributes: Any,
     ) -> Window:
         """Creates a Material UI-inspired toast window of the given elements and attributes.
 
